@@ -13,7 +13,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Cron
- * @version    $Id$
+ *
  * @link       http://www.nutime.de/
  * @since      0.9.16
  *
@@ -105,7 +105,7 @@ class phpinterface_fpm
 			$tmpdir = makeCorrectDir($this->_settings['phpfpm']['tmpdir'] . '/' . $this->_domain['loginname'] . '/');
 			if(!is_dir($tmpdir))
 			{
-				safe_exec('mkdir -p ' . escapeshellarg($tmpdir));
+				$this->getTempDir();
 			}
 			//$slowlog = makeCorrectFile($this->_settings['system']['logfiles_directory'] . $this->_domain['loginname'] . '/php-fpm_slow.log');
 
@@ -173,9 +173,9 @@ class phpinterface_fpm
 
 	/**
 	 * fpm-config file
-	 * 
+	 *
 	 * @param boolean $createifnotexists create the directory if it does not exist
-	 * 
+	 *
 	 * @return string the full path to the file
 	 */
 	public function getConfigFile($createifnotexists = true)
@@ -193,9 +193,9 @@ class phpinterface_fpm
 
 	/**
 	 * return path of fpm-socket file
-	 * 
+	 *
 	 * @param boolean $createifnotexists create the directory if it does not exist
-	 * 
+	 *
 	 * @return string the full path to the socket
 	 */
 	public function getSocketFile($createifnotexists = true)
@@ -205,8 +205,8 @@ class phpinterface_fpm
 
 		if(!is_dir($socketdir) && $createifnotexists)
 		{
-			safe_exec('mkdir -p '.$socketdir);
-			safe_exec('chown -R '.$this->_settings['system']['httpuser'].':'.$this->_settings['system']['httpgroup'].' '.$socketdir);
+			safe_exec('mkdir -p '.escapeshellarg($socketdir));
+			safe_exec('chown -R '.$this->_settings['system']['httpuser'].':'.$this->_settings['system']['httpgroup'].' '.escapeshellarg($socketdir));
 		}
 
 		return $socket;
@@ -214,9 +214,9 @@ class phpinterface_fpm
 
 	/**
 	 * fpm-temp directory
-	 * 
+	 *
 	 * @param boolean $createifnotexists create the directory if it does not exist
-	 * 
+	 *
 	 * @return string the directory
 	 */
 	public function getTempDir($createifnotexists = true)
