@@ -12,7 +12,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Formfields
- * @version    $Id: formfield.domains_add.php 112 2010-12-14 12:11:20Z d00p $
+ *
  */
 
 return array(
@@ -36,7 +36,7 @@ return array(
 						'type' => 'select',
 						'select_var' => $domains
 					),
-					'pathedit' => array(
+					'iscatchall' => array(
 						'label' => $lng['emails']['iscatchall'],
 						'type' => 'checkbox',
 						'values' => array(
