@@ -17,11 +17,31 @@
  *
  */
 
-// prevent Froxlor pages from being cached
+header("Content-Type: text/html; charset=iso-8859-1");
 
-header("Cache-Control: no-cache, must-revalidate");
+// prevent Froxlor pages from being cached
+header("Cache-Control: no-store, no-cache, must-revalidate");
 header("Pragma: no-cache");
-header("Content-type: text/html; charset=iso-8859-1");
+header('Last-Modified: ' . gmdate( 'D, d M Y H:i:s \G\M\T', time()));
+header('Expires: ' . gmdate( 'D, d M Y H:i:s \G\M\T', time()));
+
+// Prevent inline - JS to be executed (i.e. XSS) in browsers which support this,
+// Inline-JS is no longer allowed and used
+// See: http://people.mozilla.org/~bsterne/content-security-policy/index.html
+header("X-Content-Security-Policy: allow 'self'; frame-ancestors 'none'");
+
+// Don't allow to load Froxlor in an iframe to prevent i.e. clickjacking
+header('X-Frame-Options: DENY');
+
+// If Froxlor was called via HTTPS -> enforce it for the next time
+if(isset( $_SERVER['HTTPS']) && (strtolower($_SERVER['HTTPS']) != 'off' ))
+{
+	header('Strict-Transport-Security: max-age=500');
+}
+
+// Internet Explorer shall not guess the Content-Type, see:
+// http://blogs.msdn.com/ie/archive/2008/07/02/ie8-security-part-v-comprehensive-protection.aspx
+header('X-Content-Type-Options: nosniff' );
 
 // ensure that default timezone is set
 if(function_exists("date_default_timezone_set") && function_exists("date_default_timezone_get"))
@@ -306,6 +326,10 @@ if($language != 'English')
 	}
 }
 
+// Initialize our new link - class
+
+$linker = new linker('index.php', $s);
+
 /**
  * global Theme-variable
  */
@@ -320,7 +344,7 @@ if(isset($userinfo['theme']) && $userinfo['theme'] != $theme)
 }
 
 /*
- * check for custom header-graphic 
+ * check for custom header-graphic
  */
 $hl_path = 'images/'.$theme;
 $header_logo = $hl_path.'/logo.png';
@@ -371,7 +395,7 @@ if(AREA == 'admin' || AREA == 'customer')
 	if(hasUpdates($version))
 	{
 		/*
-		 * if froxlor-files have been updated 
+		 * if froxlor-files have been updated
 		 * but not yet configured by the admin
 		 * we only show logout and the update-page
 		 */
@@ -389,7 +413,7 @@ if(AREA == 'admin' || AREA == 'customer')
 							'label' => $lng['login']['logout'],
 						),
 					),
-				),		
+				),
 				'server' => array (
 					'label' => $lng['admin']['server'],
 					'required_resources' => 'change_serversettings',
@@ -429,7 +453,7 @@ elseif(isset($_GET['action']))
 else
 {
 	$action = '';
-	
+
 	// clear request data
 	if (isset($_SESSION)) {
 		unset($_SESSION['requestData']);
@@ -459,7 +483,7 @@ if($page == '')
  */
 $mail = new PHPMailer(true);
 if(PHPMailer::ValidateAddress($settings['panel']['adminmail']) !== false)
-{	
+{
 	// set return-to address and custom sender-name, see #76
 	$mail->SetFrom($settings['panel']['adminmail'], $settings['panel']['adminmail_defname']);
 	if ($settings['panel']['adminmail_return'] != '') {
