@@ -243,7 +243,7 @@ $lng['error']['domainname'] = $lng['domains']['domainname'];
 $lng['question']['question'] = 'Sikkerhedssp&oslash;rgsm&aring;l';
 $lng['question']['admin_customer_reallydelete'] = 'Er du sikker p&aring; du vil slette kunden %s? Dette kan ikke fortrydes!';
 $lng['question']['admin_domain_reallydelete'] = 'Er du sikker p&aring; du vil slette dom&aelig;net %s?';
-$lng['question']['admin_domain_reallydisablesecuritysetting'] = 'Er du sikker p&aring; du vil deaktivere disse sikkerheds indstillinger (OpenBasedir og/eller SafeMode)?';
+$lng['question']['admin_domain_reallydisablesecuritysetting'] = 'Er du sikker p&aring; du vil deaktivere disse sikkerheds indstillinger (OpenBasedir)?';
 $lng['question']['admin_admin_reallydelete'] = 'Er du sikker p&aring; du vil slette administrator %s? Alle kunder og dom&aelig;ner som h&oslash;rer hertil vil blive allokeret til &oslash;verste adminstartor.';
 $lng['question']['admin_template_reallydelete'] = 'Er du sikker p&aring; du vil slette skabelonen \'%s*\'?';
 $lng['question']['domains_reallydelete'] = 'Er du sikker p&aring; du vil slette dom&aelig;net %s?';
